@@ -5,7 +5,7 @@ function_name <- "create_embedding"
 
 test_argument_validation(
     function_name = function_name,
-    argument_name = "engine_id",
+    argument_name = "model",
     argument_type = "string",
     allow_null = FALSE
 )
